A Python module for combining *p* values of discrete tests.

* Install with:

  * ``pip install combine-pvalues-discrete``
  * ``pip3 install git+git://github.com/BPSB/combine-p-values-discrete``
  * or similar.
  
* `Documentation <https://combine-p-values-discrete.rtfd.io>`_
* `Issue Tracker <https://github.com/BPSB/combine-p-values-discrete/issues>`_ – Please report any bugs here and feel free to request features (in particular support for tests).
